source("modules/Loading/Loading.R")
source("modules/Units/Units.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")
source("modules/Indices/Indices.R")
source("modules/Downscaling/Downscaling.R")
library(igraph)

#Recipe
recipe_file <- "recipes/atomic_recipes/recipe_test_provenance1.yml"

#Loading recipe
recipe <- prepare_outputs(recipe_file)

#Loading module
data <- Loading(recipe)

#Units module
data <- Units(recipe, data)

#Calibration
data <- Calibration(recipe, data)

# Anomalies
data <- Anomalies(recipe, data)

# Compute skill metrics
skill_metrics <- Skill(recipe, data)

# Compute percentiles and probability bins
probabilities <- Probabilities(recipe, data) 

#Define provenance graph for Visualization
graph.prov <- skill_metrics$graph.prov

#Visualization
Visualization(recipe, data, graph.prov,
              skill_metrics = skill_metrics,
              probabilities = probabilities,
              significance = TRUE)

graph2json(graph.prov$graph, "/esarchive/scratch/apuiggro/sunset/graph333333.json")